<?php

/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */

/**
 * This class makes connections to the database and makes the queries.
 * Handles database related subjects.
 * @deprecated
 */
class db extends PHPDS_dependant
{
	/**
	 * If you want to capture the form html to use it in a different location set to true.
	 *
	 * @var mixed
	 */
	public $SEARCH;
	/**
	 * This will contain data with a search result message.
	 *
	 * @var mixed
	 */
	public $SEARCH_RESULTS;
	/**
	 * Override limit count results.
	 *
	 * @var mixed
	 */
	public $limit_count;
	/**
	 * Contains current filter data.
	 *
	 * @var mixed
	 */
	public $filter;
	/**
	 * Assigns query object.
	 *
	 * @var object
	 */
	public $query;

	/**
	 * This method connects to the database, if fails return a message to the template system.
	 *
	 * @deprecated
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function connect_mysql()
	{
		try {
			// Does user want a persistant connection?
			if ($this->configuration['persistent_db_connection'] == true) {
				$this->connection = mysql_pconnect($this->server, $this->dbUsername, $this->dbPassword);
			} else {
				$this->connection = mysql_connect($this->server, $this->dbUsername, $this->dbPassword);
			}
			// Create database link.
			$link = mysql_select_db($this->dbName, $this->connection);
			// Display error on link.
			if (empty($link))
					throw new PHPDS_databaseException(mysql_error(), mysql_errno());
		} catch (Exception $e) {
			$code = mysql_errno();
			throw new PHPDS_databaseException(mysql_error(), mysql_errno(), $e);
		}
	}

	/**
	 * Does the connection to the memcache server.
	 * Currently memcache is the primary supported engine.
	 * @deprecated
	 */
	public function connect_memcache()
	{
		// Check connection type.
		$this->connectMemcache();
	}

	/**
	 * Set the starting point for a SQL transaction
	 *
	 * @deprecated
	 * You should call end_transaction(true) for the queries to actually occur
	 */
	public function start_transaction()
	{
		return $this->startTransaction();
	}

	/**
	 * Commits database transactions.
	 *
	 * @deprecated
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function end_transaction()
	{
		return $this->endTransaction();
	}

	/**
	 * Checks if a database table exists.
	 * @deprecated
	 * @param string $table
	 * @return boolean
	 */
	public function table_exists($table)
	{
		return $this->tableExist($table);
	}

	/**
	 * Simple method to count number of rows in a table.
	 * @deprecated
	 * @param string $table_name
	 * @param string $column
	 * @return integer
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function count_rows($table_name, $column = false)
	{
		return $this->countRows($table_name, $column);
	}

	/**
	 * This method returns the last MySQL error as a string if there is any. It will also
	 * return the actual erroneous SQL statement if the display_sql_on_error property is
	 * set to true. This is very helpfull when debugging an SQL related problem.
	 *
	 * @deprecated
	 * @param string The actual query string.
	 * @return string
	 * @version 1.0.1
	 * @date 20100329 prevent an exception if display_sql_on_error is not set
	 * @author Don Schoeman <titan@phpdevshell.org>
	 */
	public function return_sql_error($query)
	{
		return $this->returnSqlError($query);
	}

	/**
	 * Compatibility method to allow PHPDS_db to replace db
	 *
	 * @deprecated
	 * @date				20100219
	 * @version		1.0
	 * @author		greg
	 * @see stable/phpdevshell/includes/db#new_query($query)
	 */
	public function new_query($query)
	{
		try {
			if (empty($this->defaultQuery))
					$this->defaultQuery = $this->makeQuery('PHPDS_query');
			$this->defaultQuery->sql($query);
			return $this->defaultQuery->query();
		} catch (Exception $e) {
			if (empty($this->defaultQuery))
					$msg = 'Unable to create default query: ' . $e->getMessage();
			else
					$msg = 'While running default query:<br /><pre>' . $this->defaultQuery->sql() . '</pre>' . $e->getMessage();
			throw new PHPDS_databaseException($msg, 0, $e);
		}
	}

	/**
	 * This method is used if you would like to split result pages in your PHP script.
	 *
	 * Usage Example :
	 * <code>
	 * 	$select_phonebookentries = $db->query_split
	 *   ("
	 *   	SELECT
	 *   		t1.user_id, t1.user_display_name, t1.user_name,
	 *   		t2.cell_number, t2.work_number, t2.fax_number, t2.home_number
	 *   	FROM
	 *   		_db_core_users t1
	 *   	LEFT JOIN
	 *   		_db_simple_phonebook t2
	 *   	ON
	 *   		t1.user_id = t2.user_id
	 *   	{$db->search(array(__('User ID')=>'user_id', __('Cell Number')=>'cell_number', __('Work Number')=>'work_number', __('Fax Number')=>'fax_number', __('Home Number')=>'home_number', __('User Display Name')=>'user_display_name'), 'WHERE')}
	 *   ");
	 * </code>
	 *
	 * @deprecated you should use a plugin
	 * @param string The actual query string.
	 * @param boolean If true, print page links, else dont. If no limit value is provided, all resluts will be displayed.
	 * @return array Results of query.
	 */
	public function query_split($query, $print_pages_link = true)
	{
		if (empty($this->limit_count)) {
			// Get split results. ///////////////////////////////////////////////////////////////////////////////////////////////////////
			$settings = $this->essentialSettings;
			// Assign limit count. //////////////////////////////////////////////////////////////////////////////////////////////////////
			$this->limit_count = $settings['split_results'];
		}
		// This part returns the result inside the LIMIT command set by the user. ///////////////////////////////////////////////////
		$query_replace_prefix = preg_replace('/_db_/', $this->configuration['database_prefix'], $query);
		// I am not 100% sure if this will work with SUB queries, if someone could confirm that it is working, please let me know. //
		$query_replace_prefix = preg_replace('/SELECT/', 'SELECT SQL_CALC_FOUND_ROWS', $query_replace_prefix);
		// Get the p variable to select and calculate the LIMIT from where the database needs to select data from. //////////////////
		(isset($this->security->get['p']) && $this->security->get['p'] != false) ? $current_page = $this->security->get['p'] : $current_page = 1;
		// Simple calculation to see from what result the query needs to LIMIT. /////////////////////////////////////////////////////
		$from = (($current_page - 1) * $this->limit_count);
		// Set limit property. //////////////////////////////////////////////////////////////////////////////////////////////////////
		$limit = " LIMIT $from, $this->limit_count ";
		// This here is the query where the LIMIT function is added. ////////////////////////////////////////////////////////////////
		$limit = $this->new_query($query_replace_prefix . $limit);
		// This part saves the total number of rows available without the LIMIT function effecting it. //////////////////////////////
		$total_rows = $this->new_query('SELECT FOUND_ROWS()');
		$total_rows = mysql_result($total_rows, 0, 'FOUND_ROWS()');
		// Calculated the total number of pages. ////////////////////////////////////////////////////////////////////////////////////
		$total_pages = ceil($total_rows / $this->limit_count); //////////////////////////////////////////////////////////////////////
		// END DATABASE SET /////////////////////////////////////////////////////////////////////////////////////////////////////////
		// Check to see if there is only 1 page, if so, give the end of results message.
		if ($total_pages <= 1) {
			// Show message if only 1 page exists.
			$this->SEARCH_RESULTS = sprintf($this->template->module['no_results'], ___('Showing the only page [1/1]'));
		} else {
			// Other paging calculations.
			$previous_page = $current_page - 1;
			$next_page = $current_page + 1;
			// FAST-FORWARD and REWIND functionality.
			$ff_ = floor(($total_pages / 2) + ($current_page / 2));
			$rw_ = floor($current_page / 2);
			// Make sure FF is not empty.
			if (($ff_ != 0) && ($ff_ != $total_pages) && ($ff_ != $next_page) && ($ff_ != $current_page)) {
				$ff = '<a href="' . $this->navigation->buildURL(false, "p=$ff_") . '" class="page-ff">' . $this->lang['ff_icon'] . '</a>';
			} else {
				$ff = false;
			}
			// Make sure RW is not empty.
			if (($rw_ != 0) && ($rw_ != 1) && ($rw_ != $previous_page) && ($rw_ != $current_page)) {
				$rw = '<a href="' . $this->navigation->buildURL(false, "p=$rw_") . '" class="page-rw">' . $this->lang['rw_icon'] . '</a>';
			} else {
				$rw = false;
			}
			// URL control for [First].
			if ($current_page == 1) {
				$first_page = $this->lang['first_disabled_icon'];
				$previous_page = $this->lang['previous_disabled_icon'];
			} else {
				$first_page = '<a href="' . $this->navigation->buildURL(false, "p=1") . '" class="page-first">' . $this->lang['first_icon'] . '</a>';
				$previous_page = '<a href="' . $this->navigation->buildURL(false, "p=$previous_page") . '" class="page-previous">' . $this->lang['previous_icon'] . '</a>';
			}
			// URL control for [Last].
			if ($current_page == $total_pages) {
				$last_page = $this->lang['last_disabled_icon'];
				$next_page = $this->lang['next_disabled_icon'];
				// Current records.
				$current_records = $total_rows;
			} else {
				$last_page = '<a href="' . $this->navigation->buildURL(false, "p=$total_pages") . '" class="page-last">' . $this->lang['last_icon'] . '</a>';
				$next_page = '<a href="' . $this->navigation->buildURL(false, "p=$next_page") . '" class="page-next">' . $this->lang['next_icon'] . '</a>';
				// Current records.
				$current_records = $current_page * $this->limit_count;
			}
			// Compile result strings.
			$paging_back = $first_page . $rw . $previous_page;
			$paging_results = ___('&nbsp;[') . $current_page . ___('/') . $total_pages . ___('&nbsp;Pages') . ___(']&nbsp;') . ___('&nbsp;[') . $current_records . ___('/') . $total_rows . ___('&nbsp;Records') . ___(']&nbsp;');
			$paging_forward = $next_page . $ff . $last_page;
			// This part creates the links to the pages.
			$this->SEARCH_RESULTS = sprintf($this->template->module['results'], $paging_back, $paging_results, $paging_forward);
		}
		// Check to see if pages links needs to be print out to the browser.
		if ($print_pages_link == true) {
			print $this->SEARCH_RESULTS;
		}
		// Return limit.
		return $limit;
	}

	/**
	 * This very usefull method is used to implement a search form in your script.
	 * Users can seach for everything using the * or % character.
	 *
	 * @deprecated you should use a plugin
	 *
	 * @param array Array containing column names you would like the method to search in.
	 * @param string Can have values 'WHERE', 'AND', 'OR' depending on your query.
	 * @param array Additional ORDER BY columns, i.e. (0=>'column1 ASC', 1=>'column2 DESC')
	 * @param string Allows additional HTML to be appended within the search form
	 * @param boolean Would you like to return the search form instead of printing it out.
	 *
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function search($column_array = false, $where_and_or = false, $order_by_array = false, $append_html = false, $return_html = false)
	{
		if (!empty($this->configuration['user_id'])) {
			// Lets query search filters from database first.
			$search_filter_db = $this->new_query("
				SELECT
					t1.search_id, t1.filter_search, t1.filter_order, t1.filter_by, t1.exact_match
				FROM
					_db_core_filter t1
				WHERE
					t1.menu_id = '{$this->configuration['m']}'
				AND
					t1.user_id = '{$this->configuration['user_id']}'
				LIMIT
					0,1
			");
			// Collect values.
			$this->filter = mysql_fetch_array($search_filter_db);
		} else if (!empty($_SESSION['filter_search']) && empty($this->configuration['user_id'])) {
			$this->filter['filter_search'] = $_SESSION['filter_search'];
			$this->filter['filter_order'] = $_SESSION['filter_order'];
			$this->filter['filter_by'] = $_SESSION['filter_by'];
			$this->filter['exact_match'] = $_SESSION['exact_match'];
		}
		// Check if method search variables are valid.
		if (is_array($column_array) && !empty($where_and_or)) {
			// Lets save the new values to the database.
			if (!empty($this->security->post['search'])) {
				// Set filter array.
				$this->filter['filter_search'] = $this->security->post['search_field'];
				$this->filter['filter_order'] = $this->security->post['filter_module_order'];
				$this->filter['filter_by'] = $this->security->post['filter_module_by'];
				$this->filter['exact_match'] = $this->security->post['exact_match'];
				// Define.
				if (empty($this->filter['search_id'])) $this->filter['search_id'] = false;
				// Lets update the database with the latest search filter.
				if ($this->configuration['user_id'] != 0) {
					$this->new_query("
						REPLACE INTO
							_db_core_filter
						VALUES
							('{$this->filter['search_id']}', '{$this->configuration['user_id']}', '{$this->configuration['m']}', '{$this->filter['filter_search']}', '{$this->filter['filter_order']}', '{$this->filter['filter_by']}', '{$this->filter['exact_match']}')
					");
				} else {
					$_SESSION['filter_search'] = $this->security->post['search_field'];
					$_SESSION['filter_order'] = $this->security->post['filter_module_order'];
					$_SESSION['filter_by'] = $this->security->post['filter_module_by'];
					$_SESSION['exact_match'] = $this->security->post['exact_match'];
				}
			}
			// Check which options to select.
			if ($this->filter['filter_order'] == 'ASC') {
				$filter_module_order1 = 'selected';
				$filter_module_order2 = false;
			} else {
				$filter_module_order2 = 'selected';
				$filter_module_order1 = false;
			}
			// Check if checkbox should be checked.
			if ($this->filter['exact_match'] == 2) {
				$check_exact_match_2 = 'selected';
				$check_exact_match_1 = false;
			} else {
				$check_exact_match_1 = 'selected';
				$check_exact_match_2 = false;
			}
			// Set.
			$display_columns = false;
			$order_column_option = false;
			$search_columns = false;
			// Create info and database query string.
			foreach ($column_array as $name_key => $column) {
				// Create information string.
				if (is_string($name_key)) {
					$defined_name = $name_key;
					$display_columns .= $defined_name . '<br />';
				} else {
					$defined_name = $column;
					$display_columns .= $defined_name . '<br />';
				}
				// Mark selected column option.
				if ($this->filter['filter_by'] == $column) {
					// Build by options.
					$order_column_option .= "<option value='$column' selected>$defined_name</option>";
				} else {
					// Build by options.
					$order_column_option .= "<option value='$column'>$defined_name</option>";
				}
				// Exact match?
				if ($this->filter['exact_match'] == 2) {
					// Create databse query string exact.
					$search_columns .= " $column LIKE '{$this->filter['filter_search']}' OR ";
				} else {
					// Create databse query string search all.
					$search_columns .= " $column LIKE '%{$this->filter['filter_search']}%' OR ";
				}
			}
			// Glue and ready database string.
			if (strlen($this->filter['filter_search']) != 0) {
				// Remove last OR.
				$search_columns = $this->core->right_trim($search_columns, ' OR ');
				// Glue final database string.
				$database_string = ' ' . $where_and_or . ' (' . $search_columns . ') ';
			} else {
				// Return nothing if no $this->filter['filter_search'] value.
				$database_string = false;
			}
		}
		// Create HTML form.
		$this->SEARCH = sprintf($this->template->module['search'], $this->navigation->selfUrl(), $this->filter['filter_search'], $this->template->tip(___('Search by : <br>') . $display_columns), $order_column_option, $filter_module_order1, ___('Ascending'), $filter_module_order2, ___('Descending'), $check_exact_match_1, ___('Find All'), $check_exact_match_2, ___('Strict Search'), $this->security->search_validation() . $append_html);
		// Set.
		$order_str = false;
		// Database order.
		if (!empty($this->filter['filter_by']) && ($this->filter['filter_order'] != 'ASC' || $this->filter['filter_order'] != 'DESC')) {
			if (is_array($order_by_array)) {
				foreach ($order_by_array as $element) {
					$order_str .= $order_str . $element . ', ';
				}
			}
			// Set order by.
			$order_by = " ORDER BY $order_str {$this->filter['filter_by']}\n {$this->filter['filter_order']} ";
		} else {
			if (is_array($order_by_array)) {
				$order_by_count = count($order_by_array);
				if ($order_by_count > 0) {
					for ($i = 0; $i < $order_by_count; $i++) {
						if ($i == $order_by_count - 1) {
							$order_str .= $order_by_array[$i];
						} else {
							$order_str .= $order_by_array[$i] . ', ';
						}
					}
					$order_by = " ORDER BY $order_str";
				}
			}
		}
		// Output search html.
		if (!empty($this->SEARCH) && empty($return_html)) {
			print $this->SEARCH;
		}
		// Define.
		if (empty($order_by)) $order_by = false;
		// Return database query string.
		return $database_string . $order_by;
	}

	/**
	 * Method logs menu access per user.
	 * @deprecated
	 */
	public function log_menu_access()
	{
		$this->logMenuAccess();
	}

	/**
	 * This method logs error and success entries to the database.
	 * @deprecated
	 * @param integer $log_type
	 * @param string $log_description
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 *
	 * @version 1.0.1 	Changed mysql_escape_string() to mysql_real_escape_string() [see http://www.php.net/manual/en/function.mysql-escape-string.php ]
	 */
	public function log_this()
	{
		$this->logThis();
	}

	/**
	 * This function gets all role id's for a given user id, while returning a string divided by ',' character or an array with ids.
	 * To pull multiple user roles, provide a string for $user_ids like so: '2,5,10,19'.
	 * @deprecated
	 * @param string $user_id
	 * @param boolean $return_array
	 * @return mixed If $return_array = false a comma delimited string will be returned, else an array.
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function get_roles($user_id = false, $return_array = false)
	{
		return $this->getRoles($user_id, $return_array);
	}

	/**
	 * This function gets all group id's for given user ids, while returning a string divided by ',' character or an array with ids.
	 * To pull multiple user groups, provide a string for $user_ids like so : '2,5,10,19'.
	 * @deprecated
	 * @param string $user_id Leave this field empty if you want skip if user is root.
	 * @param boolean $return_array
	 * @param string $alias_only If you would like only items of a certain alias to be called.
	 * @return mixed If $return_array = false a comma delimited string will be returned, else an array.
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function get_groups($user_id = false, $return_array = false, $alias_only = false)
	{
		return $this->getGroups($user_id, $return_array, $alias_only);
	}

	/**
	 * Simple check to see if a certain role exists.
	 * @deprecated
	 * @param integer $role_id
	 * @return boolean
	 */
	public function role_exist($role_id)
	{
		return $this->roleExist($role_id);
	}

	/**
	 * Simple check to see if a certain group exists.
	 * @deprecated
	 * @param integer $group_id
	 * @return boolean
	 */
	public function group_exist($group_id)
	{
		return groupExist($group_id);
	}

	/**
	 * Check if user belongs to given role. Returns true if user belongs to user role.
	 * @deprecated
	 * @param integer $user_id
	 * @param integer $user_role
	 * @return boolean Returns true if user belongs to user role.
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function belongs_to_role($user_id = false, $user_role)
	{
		return $this->belongsToRole($user_id, $user_role);
	}

	/**
	 * Check if user belongs to given group. Returns true if user belongs to user group.
	 * @deprecated
	 * @param integer $user_id
	 * @param integer $user_group
	 * @return boolean Returns true if user belongs to user group.
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function belongs_to_group($user_id = false, $user_group)
	{
		return $this->belongsToGroup($user_id, $user_group);
	}

	/**
	 * Creates a query to extend a role query, it will return false if user is root so everything can get listed.
	 * This is meant to be used inside an existing role query.
	 * @deprecated
	 * @param string $query_request Normal query to be returned if user is not a root user.
	 * @param string $query_root_request If you want a query to be processed for a root user seperately.
	 * @return mixed
	 */
	public function set_role_query($query_request, $query_root_request = false)
	{
		return $this->setRoleQuery($query_request, $query_root_request);
	}

	/**
	 * Creates a query to extend a group query, it will return false if user is root so everything can get listed.
	 * This is meant to be used inside an existing group query.
	 * @deprecated
	 * @param string $query_request Normal query to be returned if user is not a root user.
	 * @param string $query_root_request If you want a query to be processed for a root user seperately.
	 * @return mixed
	 */
	public function set_group_query($query_request, $query_root_request = false)
	{
		return $this->setGroupQuery($query_request, $query_root_request);
	}

	/**
	 * Generates a prefix for plugin general settings.
	 * @deprecated
	 * @param string $custom_prefix
	 * @return string Complete string with prefix.
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function settings_prefix($custom_prefix = false)
	{
		return $this->settingsPrefix($custom_prefix);
	}

	/**
	 * Used to write general plugin settings to the database.
	 * Class will always use plugin name as prefix for settings if no custom prefix is provided.
	 * <code>
	 * // Example:
	 * $db->write_settings(array('setting_name'=>'value')[,'Example']);
	 * </code>
	 * @deprecated
	 * @param array $write_settings This array should contain settings to write.
	 * @param string $custom_prefix If you would like to have a custom prefix added to your settings.
	 * @return boolean On success true will be returned.
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function write_settings($write_settings, $custom_prefix = false)
	{
		return $this->writeSettings($write_settings, $custom_prefix);
	}

	/**
	 * Delete all settings stored by a given plugins name, is used when uninstalling a plugin.
	 *
	 * Example:
	 * <code>
	 * delete_settings(false, 'SimplePhonebook')
	 * </code>
	 * @deprecated
	 * @param array $settings_to_delete
	 * @param string $custom_prefix
	 * @return boolean
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function delete_settings($settings_to_delete = false, $custom_prefix = false)
	{
		return $this->deleteSetting($settings_to_delete, $custom_prefix);
	}

	/**
	 * Loads and returns required settings from database.
	 * Class will always use plugin name as prefix for settings if no custom prefix is provided.
	 * @deprecated
	 * @param array $settings_required
	 * @param string $prefix This allows you to use a prefix value of your choice to select a setting from another plugin, otherwise PHPDevShell will be used.
	 * @return array An array will be returned containing all the values requested.
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function get_settings($settings_required = false, $custom_prefix = false)
	{
		return $this->getSettings($settings_required, $custom_prefix);
	}

	/**
	 * Used to get all essential system settings from the database, preventing multiple queries.
	 * @deprecated
	 * @return array Contains array with essential settings.
	 */
	public function get_essential_settings()
	{
		// Pull essential settings and assign it to essential_settings.
		$this->getEssentialSettings();
	}

	/**
	 * Determines whether the specified search string already exists in the specified field within the supplied table.
	 * Optional: Also looks at an id field (typically the primary key of a table) to make sure that the record you are working with
	 * is NOT included in the search.
	 * Usefull when modifying an existing record and you need first to check if another record with the same value doesn't already exist.
	 *
	 * Please note that this function is not case sensitive.
	 *
	 * Usage Example :
	 * <code>
	 * 	if ($db->does_record_exist('_db_core_users', array('user_name', 'user_email'), array('root', 'titan@phpdevshell.org'), 'user_id', '123'))
	 * 	{
	 * 		$this->template->debugStr = "Found!";
	 * 	}
	 * 	else
	 * 	{
	 * 		$this->template->debugStr = "Not Found!";
	 * 	}
	 *
	 *  // Or you could use single values instead of arrays.
	 * 	if ($db->does_record_exist('_db_core_users', 'user_name', 'root', 'user_id', '123'))
	 * 	{
	 * 		$this->template->debugStr = "Found!";
	 * 	}
	 * 	else
	 * 	{
	 * 		$this->template->debugStr = "Not Found!";
	 * 	}
	 * </code>
	 * @deprecated
	 * @param string The name of the database table.
	 * @param mixed The array names of the columns in which to look for the search strings, a single value can also be given.
	 * @param mixed In the same order as $search_column_name array, the search strings in array that should not be duplicated, a single value can also be given.
	 * @param string The name of the primary key column name of the record you will be updating.
	 * @param string The value of the primary key of the record you will be updating that should not be included in the search.
	 * @return boolean If TRUE is returned it means the record already exists, FALSE means the record doesn't exist.
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function does_record_exist($table_name, $search_column_names, $search_field_values, $column_name_for_exclusion = false, $exclude_field_value = false)
	{
		// Check if we should exclude the id.
		return $this->doesRecordExist($table_name, $search_column_names, $search_field_values, $column_name_for_exclusion, $exclude_field_value);
	}

	/**
	 * Pulls all registered hooks from the database and prepares them in an array.
	 * @deprecated
	 * @return array
	 */
	public function get_hooks()
	{
		// Get all registered hooks for this script.
		return false;
	}

	/**
	 * Get a single result from database with minimal effort.
	 * @deprecated
	 * @param string $from_table_name
	 * @param string $select_column_name
	 * @param string $where_column_name
	 * @param string $is_equal_to_column_value
	 * @return string
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function select_quick($from_table_name, $select_column_name, $where_column_name, $is_equal_to_column_value)
	{
		return $this->selectQuick($from_table_name, $select_column_name, $where_column_name, $is_equal_to_column_value);
	}

	/**
	 * Delete data from the database with minimal effort.
	 * @deprecated
	 * @param string $from_table_name
	 * @param string $where_column_name
	 * @param string $is_equal_to_column_value
	 * @param string $return_column_value
	 * @return string
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function delete_quick($from_table_name, $where_column_name, $is_equal_to_column_value, $return_column_value = false)
	{
		return $this->deleteQuick($from_table_name, $where_column_name, $is_equal_to_column_value, $return_column_value);
	}

	/**
	 * This method is used to generate a new name value for a particular string in the database.
	 *
	 * Usage Example :
	 * <code>
	 *  // This code generates a copy of the text "Some Value". The name_of_new_copy function
	 *  // checks that it doesn't duplicate the name.
	 *  $result = $db->name_of_new_copy('PHPDS_table', 'some_field', 'Some Value');
	 *
	 *  // name_of_new_copy() returns 'Copy of Some Value', unless 'Copy of Some Value' already exists. If
	 *  // it does, the function will return with 'Copy (x) of Some Value' where x is the next available
	 *  // number that is not in use.
	 * </code>
	 *
	 * @deprecated
	 * @param string The name of the table to search within.
	 * @param string The fieldname to search withing.
	 * @param string The original text to search for.
	 * @author Don Schoeman <don@delphexonline.com>
	 */
	function name_of_new_copy($table_name, $name_field, $orig_name)
	{
		return $this->nameOfNewCopy($table_name, $name_field, $orig_name);
	}

	/**
	 * Writes array of all the installed plugins on the system.
	 * @deprecated
	 * @author Jason Schoeman <titan@phpdevshell.org>
	 */
	public function installed_plugins()
	{
		$this->installedPlugins();
	}

	/**
	 * Writes new data to cache.
	 * @deprecated
	 * @param string $cache_unique_name
	 * @param mixed $cache_data
	 */
	public function cache_write($cache_unique_name, $cache_data)
	{
		return $this->cacheWrite($cache_unique_name, $cache_data);
	}

	/**
	 * Return exising cache result to required item.
	 * @deprecated
	 * @param mixed $cache_unique_name
	 * @return mixed
	 */
	public function cache_read($cache_unique_name)
	{
		return $this->cacheRead($cache_unique_name);
	}

	/**
	 * Clear specific or all cache memory.
	 * @deprecated
	 * @param mixed $cache_unique_name
	 */
	public function cache_clear($cache_unique_name = false)
	{
		$this->cacheClear($cache_unique_name);
	}

	/**
	 * Checks if we have an empty cache container.
	 * @deprecated
	 * @param mixed $cache_unique_name
	 * @return boolean
	 */
	public function cache_empty($cache_unique_name)
	{
		return $this->cacheEmpty($cache_unique_name);
	}
}

?>