<?php

/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */
class PluginActivation extends PHPDS_controller
{

	/**
	 * Activates a plugin
	 * @author Jason Schoeman
	 * @since 06 July 2010
	 */
	public function execute()
	{
		// Require plugin manager ////////////////////////////////////////////////////////////////////////////////////////////////
		$pluginmanager = $this->factory('pluginManager');
		// Require JS.
		$this->template->addJsFileToHead('themes/cloud/js/showhide/jquery.showhide.js');
		//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
		// Header information
		$this->template->heading(_('Plugin Activation'));
		$this->template->info(_('Before a plugin item can be configured or used in any way, it needs to be installed first. On installation or uninstall database tables might be installed or deleted.'));

		// Plugin activation starts.
		if (isset($this->security->post) && $this->user->isRoot()) {
			/////////////////////////////////////////////////////////////////////
			// When save is submitted... ////////////////////////////////////////
			/////////////////////////////////////////////////////////////////////
			// Install   = 1 ////////////////////////////////////////////////////
			// Uninstall = 2 ////////////////////////////////////////////////////
			// Reinstall = 3 ////////////////////////////////////////////////////
			// Upgrade   = 4 ////////////////////////////////////////////////////
			/////////////////////////////////////////////////////////////////////
			if (isset($this->security->post['install'])) {
				// Execute plugin method.
				$pluginmanager->setPlugin($this->security->post['plugin'], 'install');
			} else if (isset($this->security->post['uninstall'])) {
				// Execute plugin method.
				$pluginmanager->setPlugin($this->security->post['plugin'], 'uninstall');
			} else if (isset($this->security->post['reinstall'])) {
				// Execute plugin method.
				$pluginmanager->setPlugin($this->security->post['plugin'], 'reinstall');
			} else if (isset($this->security->post['upgrade'])) {
				// Execute plugin method.
				$pluginmanager->setPlugin($this->security->post['plugin'], 'upgrade', $this->security->post['version']);
			} else if (isset($this->security->post['auto_upgrade'])) {
				// Execute plugin method.
				$pluginmanager->setPlugin($this->security->post['plugin'], 'auto_upgrade');
			} else if (isset($this->security->post['set_logo'])) {
				// Execute plugin method.
				$pluginmanager->setPlugin($this->security->post['plugin'], 'set_logo');
			}
			/////////////////////////////////////////////////////////////////////
			// End save is submitted... /////////////////////////////////////////
			/////////////////////////////////////////////////////////////////////
		}
		/////////////////////////////////////////////////
		// Call current plugins status from database. ///
		/////////////////////////////////////////////////
		// Read plugin directory.
		$RESULTS = $this->db->invokeQuery('PHPDS_readPluginsQuery', $this->db->invokeQuery('PHPDS_currentPluginStatusQuery'));

		// Load views.
		$view = $this->factory('views');

		// Set Array.
		$view->set('RESULTS', $RESULTS);

		// Output Template.
		$view->show();
	}
}

return 'PluginActivation';
