<?php

/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */
class EmailToken extends PHPDS_controller
{

	/**
	 * Emails Tokens
	 * @author Jason Schoeman [titan@phpdevshell.org], Ross Kuyper
	 * @since 06 July 2010
	 */
	public function execute()
	{
		//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
		// Load Extra Classes ////////////////////////////////////////////////////////////////////////////////////////////////////
		$email = $this->factory('mailer'); //////////////////////////////////////////////////////////////////////////////////////////////////
		//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
		$this->template->heading(_('Email Token'));
		$this->template->info(_('Allow invitations to be sent to certain email addresses. After user receives and activates token, one token point will be deducted.'));
		// Registration page.
		$settings = $this->db->essentialSettings;

		// Get token data from database.
		$edit = $this->db->invokeQuery('PHPDS_getTokenDataQuery', $this->security->request['token_id']);
		// Check if we have a token id.
		if (empty($edit['token_id'])) {
			$this->template->warning('I need a token ID in order to send tokens! I cannot continue.');
		} else {
			// Create send token to recipients.
			if (!empty($this->security->post['email_token_to'])) {
				$edit['email_token_to'] = $this->security->post['email_token_to'];
			} else {
				$edit['email_token_to'] = false;
			}
			// Create email subject.
			if (empty($this->security->post['token_subject'])) {
				$edit['token_subject'] = sprintf(_("%s Registration Token Credit."), $this->configuration['scripts_name_version']);
			} else {
				$edit['token_subject'] = $this->security->post['token_subject'];
			}
			// Create email subject.
			if (empty($this->security->post['token_message'])) {
				// Create registration URL.
				$token_url = "{$this->configuration['absolute_url']}/index.php?m={$settings['registration_page']}&token_key={$edit['token_key']}";
				$registration_url = "{$this->configuration['absolute_url']}/index.php?m={$settings['registration_page']}";
				$edit['token_message'] = sprintf(_("Dear User,\r\n\r\nYou have received a Registration Token Key, enabling you to register for %1\$s on %2\$s.\r\n\r\nTo activate your key please click on the link below,\r\n%3\$s\r\n\r\nIf you cannot click on the link, copy and paste the URL to your browser.\r\n\r\nAlternatively you can type in your key,\r\n%4\$s\r\nhere,  %5\$s\r\n\r\nThank You,\r\n%6\$s."), $edit['token_name'], $this->configuration['scripts_name_version'], $token_url, $edit['token_key'], $registration_url, $this->configuration['user_display_name']);
			} else {
				$edit['token_message'] = $this->security->post['token_message'];
			}
			// If the user posts, run the checks and send the email script.
			if (!empty($this->security->post['send_mail'])) {

				// Email error checking.
				if (!empty($edit['token_subject']) || !empty($edit['token_message']) || !empty($edit['email_token_to'])) {

					// Check if we have the sender address.
					if (empty($this->configuration['user_email'])) {
						$this->template->warning('I cannot find your email address, please make sure you have it configured in your preferences.');
						$error[1] = true;
					}
					if (empty($error)) {
						// Create complete mail string.
						$mail_to_recipients = "{$this->configuration['user_email']},{$edit['email_token_to']}";
						// Loop and send mail, we do not want other to see who else received mail.
						$recipients_array = str_replace(' ', '', explode(',', $mail_to_recipients));
						// Loop to.
						foreach ($recipients_array as $email_address_to) {
							if ($email->sendmail("$email_address_to", $edit['token_subject'], $edit['token_message'])) {
								$this->template->ok(sprintf(_('Registration token "%s" was successfully send to %s.'), $edit['token_name'], $email_address_to));
							} else {
								$this->template->warning(sprintf(_('An unknown error occurred while trying to send registration token email to %s.'), $email_address_to));
							}
						}
					}
				} else {
					$this->template->warning(_('You have missed mandatory form fields, please revise!'), false, false);
				}
			}

			// Load views.
			$view = $this->factory('views');

			// Set Array.
			$view->set('e', $edit);

			// Set Button.
			$view->set('email_token', _('Email Token'));

			// Set Values.
			$view->set('self_url', $this->navigation->selfUrl());

			// Output Template.
			$view->show();
		}
	}
}

return 'EmailToken';