<?php

/**
 * PHPDevShell is a RAD Framework aimed at developing administrative applications.
 *
 * @package PHPDevShell
 * @link http://www.phpdevshell.org
 * @copyright Copyright (C) 2007 Jason Schoeman, All rights reserved.
 * @license GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 * @author Jason Schoeman, Contact: titan [at] phpdevshell [dot] org.
 *
 * Copyright notice: See readme/notice
 * By using PHPDevShell you agree to notice and license, if you dont agree to this notice/license you are not allowed to use PHPDevShell.
 */

/**
 * Controller Class: Handles Login Requests
 * @author Jason Schoeman
 * @return string
 */
class LoginPage extends PHPDS_controller
{

	/**
	 * Execute Controller
	 * @author Jason Schoeman
	 */
	public function execute()
	{
		// Load views.
		$view = $this->factory('views');
		// Timestamp
		$timestamp = $this->configuration['time'];
		// Get some default settings.
		$settings = $this->db->getSettings(array('redirect_login', 'login_message'));
		// Define.
		$redirect = false;

		// Controls the user logout
		if ((!empty($this->security->post['logout']) || !empty($this->security->get['logout'])) && $this->user->isLoggedIn()) {

			// Action information.
			$this->template->heading(_('Processing log-out...'));
			$this->template->busy(sprintf(_('You logged out %s and will now be redirected.'), $this->configuration['user_display_name']));
			// Displays login graphics.
			$view->show('logout.tpl');
			// Call logout script.
			$this->user->logout(true);
			$this->navigation->redirect($this->navigation->selfUrl(), 2);
		}
		// Controls the user login
		if (!empty($this->security->post['login'])) {

			if (empty($this->security->post['user_name']) || empty($this->security->post['user_password'])) {
				// Show login screen again.
				$this->template->heading(_('Processing incomplete log-in...'));
				$this->template->warning(_('You did not complete both the username and password fields.'));
				$view->show('logout-wrong.tpl');
				// Redirect to login.
				$this->navigation->redirect($this->navigation->selfUrl(), 2);
			} else {

				if ($this->user->login($this->security->post['user_name'], $this->security->post['user_password'])) {

					// Action information.
					$this->template->heading(_('Processing log-in...'));
					$this->template->ok(sprintf(_('You logged-in as %s and will now be redirected.'), $this->security->post['user_name']));
					// Displays login graphics.
					$view->show('login.tpl');
					// Get default redirect login.
					$redirect_setting_url = $this->navigation->buildURL($settings['redirect_login']);
					// Check if redirect to other page needed...
					if (!empty($this->security->post['redirect'])) {
						$redirect = $this->security->post['redirect'];
					} else if (!empty($redirect_setting_url)) {
						$redirect = $redirect_setting_url;
					} else {
						$redirect = $this->navigation->selfUrl();
					}
					// Finally we can redirect the page to where the user would want to go.
					$this->navigation->redirect($redirect, 2);
				} else {
					$this->template->heading(_('Processing wrong log-in...'));
					$this->template->warning(_('You used an invalid username or password. Remember, it is case sensitive.'));
					$view->show('logout-wrong.tpl');
					// Redirect to login.
					$this->navigation->redirect($redirect, 2);
				}
			}
		}
		if ($this->user->isLoggedIn() && (empty($this->security->post['login']) && empty($this->security->request['logout']))) {
			// Header info.
			$this->template->heading(_('Log-Out Page'));
			$this->template->info(sprintf(_('Welcome to the log-in and log-out page for %s.'), $this->configuration['scripts_name_version']));
			// Check if we have a login message to display.
			if (!empty($settings['login_message']))
					$this->template->message($settings['login_message']);
			// Login notice information.
			$this->template->ok(_('You are logged-in as ') . $this->configuration['user_display_name']);
			// Clears all persistent cookies from the database
			if ((!empty($this->security->post['pclear']) || !empty($this->security->get['pclear'])) && $this->user->isLoggedIn()) {
				// Clear the database
				if ($this->db->invokeQuery('PHPDS_clearPersistentDBQuery', $this->configuration['user_id'])) {
					$this->template->ok(_('All persistent cookies were cleared.'));
				}
			}
			// Query all logs.
			$RESULTS = $this->db->invokeQuery('PHPDS_ReadLogsQuery');

			// Set Array.
			$view->set('pagination', $RESULTS['pagination']);
			$view->set('searchForm', $RESULTS['searchForm']);
			$view->set('th', $RESULTS['th']);
			$view->set('RESULTS', $RESULTS['list']);

			// Set Buttons.
			$view->set('log_out', _('Log-Out'));
			$view->set('p_clear', _('Clear Persistent'));

			// Set Values.
			$view->set('self_url', $this->navigation->selfUrl());
			$view->set('post_validation', $this->security->postValidation());

			// Output Template.
			$view->show();
		} else if (empty($this->security->post['login']) && empty($this->security->request['logout'])) {
			// Header info.
			$this->template->heading(_('Log In Page'));
			$this->template->info(_('Please fill in your Username and Password. Letters are case sensitive.'));
			// Check if we have a login message to display.
			if (!empty($settings['login_message']))
					$this->template->message($settings['login_message']);
			// Login template.
			$this->template->loginTemplate($this->navigation->selfUrl());
		}
	}
}

return 'LoginPage';
