<?php
/*
 * This page will be displayed whenever an unhandled error or exception occurs in PHPDevShell
 */
// If the error occured during an AJAX request, we'll send back a lightweight ouput
if (PU_isAJAX()) {
	if (!empty($message)) {
		print "$message - file $filepath line $lineno";
	} else {
		print 'Unknown error';
	}
} else {
// for a regular request, we present a nicely formatted html page; if provided, an extended description of the error is displayed
?>
<!DOCTYPE HTML>
<!--
		____      _     _    ____      _____                    __
		/    )    /    /     /    )    /    )                 /    )    /             /    /
---/____/----/___ /-----/____/----/----/-----__-----------\--------/__-----__----/----/-
	/         /    /     /         /    /    /___)  | /      \      /   )  /___)  /    /
_/_________/____/_____/_________/____/____(___ ___|/___(____/____/___/__(___ __/____/___
Copyright (C) 2010 Jason Schoeman, All rights reserved. [http://www.phpdevshell.org]
GNU/LGPL, see readme/licensed_under_lgpl or http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
-->
<html lang="en">
	<head>
		<title>Serious Error Encountered</title>
		<meta charset=UTF-8>
		<meta http-equiv="X-UA-Compatible" content="IE=8" />
		<meta name="keywords" content="critical, error" />
		<meta name="description" content="We encountered an error" />
		<link rel="stylesheet" href="<?php echo $aurl ?>/themes/cloud/css/reset.css" type="text/css" media="screen, projection" />
		<link rel="stylesheet" href="<?php echo $aurl ?>/themes/cloud/jquery/css/ui-lightness/jquery-ui.css" type="text/css" media="screen, projection" />
		<link rel="stylesheet" href="<?php echo $aurl ?>/themes/cloud/css/general.css" type="text/css" media="screen, projection" />
		<link rel="stylesheet" href="<?php echo $aurl ?>/themes/cloud/css/notifications.css" type="text/css" media="screen, projection" />
		<script type="text/javascript" src="<?php echo $aurl ?>/themes/cloud/jquery/js/jquery-1.4.3.min.js"></script>
		<script type="text/javascript" src="<?php echo $aurl ?>/themes/cloud/jquery/js/jquery-ui-1.8.5.custom.min.js"></script>
		<script type="text/javascript" src="<?php echo $aurl ?>/themes/cloud/js/showhide/jquery.showhide.js"></script>
	</head>
	<!-- PHPDevShell Main Body -->
	<body class="ui-widget">
		<?php
			if ($special) {
				list($msg, $causes) = $this->specialError($special);
				?>

				<article class="ui-widget-content ui-corner-all" style="margin:2em; padding:2em;">
				<p class="ui-state-error ui-corner-all"><?php  print $msg?></p>
				<p>Possible causes are:</p>
				<?php
					foreach($causes as $cause) {
						list($title, $text) = $cause;
						print "<p><strong>$title</strong>$text</p>";
					}
				?>
				</article>
				<?php
			}
		?>
		<?php if (!empty($message)) { ?>
		<article class="ui-widget-content ui-corner-all" style="margin:2em; padding:2em;">
			<h1 class="ui-state-error ui-corner-all">Uncaught Exception while running</h1>
			<p>This page will try to provide as much information as possible so you can track down (and hopefully fix) the problem.</p>

			<h2>The error</h2>

			<p>The message of the error is as follow:</p>
			<blockquote>
			<p class="ui-state-error ui-corner-all"><?php echo $message; ?></p>
			<p><?php echo $extendedMessage; ?></p>
			</blockquote>

			<p>The error occurred in file <strong><?php echo $filepath?></strong> at line <strong><?php echo $lineno?></strong></p>
			<blockquote>
			<p><?php echo $filefragment?></p>
			</blockquote>


			<h2>The configuration</h2>
			<h3>Configuration files actually used:</h3>
			<?php echo $conf['used']; ?>
			<h3>Configuration files which would have been used if they were present:</h3>
			<?php echo $conf['missing']; ?>

			<h2>The Backtrace:</h2>
			<p>All relative file pathes are relative to the server root (namely <tt><?php echo $_SERVER['DOCUMENT_ROOT']; ?>/ )</tt></p>
			<p>Click on the Book icon to access online documentation.</p>
			<table>
				<thead>
					<tr>
						<th>File path (relative)</th>
						<th>Line</th>
						<th>Call (with arguments)</th>
					</tr>
				</thead>
				<tbody>
					<?php echo $bt; ?>
				</tbody>
			</table>
		</article>
		<?php } else { ?>
		<article class="ui-widget-content ui-corner-all" style="margin:2em; padding:2em;">
			<h1 class="ui-state-error ui-corner-all">An error has occured...</h1>
			<p>An error has occurred while trying to provide you with the requested resource.</p>
			<p>The site administrator have been informed and will fix the problem as soon as possible.</p>
			<p>Sorry for the inconvenience, please come back later...</p>
		</article>
		<?php }?>
	</body>
</html>
<?php } ?>